﻿// <copyright file="ArqCs.ErrorException.cs" company="dev.arqendra.net">
// v1.0
// </copyright>
// <author>TrV</author>
// <email>dev(at)arqendra(dot)net</email>
// <date>2010-01</date>
// <summary>Class ErrorException.</summary>

using System;
using System.Runtime.Serialization;

namespace ArqCs
{
    /// <summary>
    /// Runtime error exception.
    /// </summary>
    [Serializable]
    public class ErrorException : Exception
    {
        /// <summary>
        /// Initializes a new instance of the ErrorException class with default values.
        /// </summary>
        public ErrorException()
        {
        }

        /// <summary>
        /// Initializes a new instance of the ErrorException class with given error message.
        /// </summary>
        /// <param name="message">Error message.</param>
        public ErrorException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the ErrorException class with given error message and reference to source exception.
        /// </summary>
        /// <param name="message">Error message.</param>
        /// <param name="innerException">Source exception.</param>
        public ErrorException(string message, Exception innerException)
            : base(message, innerException)
        {
        }

        /// <summary>
        /// Initializes a new instance of the ErrorException class with given serialization information.
        /// </summary>
        /// <param name="info">Serialized data.</param>
        /// <param name="context">Information on source or destination.</param>
        protected ErrorException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }
    }
}
