// <copyright file="ArqCs.ExecutableObserver.cs" company="dev.arqendra.net">
// v1.5
// </copyright>
// <author>TrV</author>
// <email>dev(at)arqendra(dot)net</email>
// <date>2010-12</date>
// <summary>Class ExecutableObserver.</summary>

namespace ArqCs
{
    #region ExecutableObserver
    /// <summary>
    /// Observes executable.
    /// </summary>
    public class ExecutableObserver : ProcessObserver
    {
        #region constructors
        /// <summary>
        /// Initializes a new instance of the ExecutableObserver class.
        /// </summary>
        /// <param name="fileName">Observed file name.</param>
        /// <param name="scanFrequency">Scan frequency [seconds].</param>
        public ExecutableObserver(string fileName, int scanFrequency)
            : base(string.Empty, fileName, scanFrequency)
        {
            this.Kind = ProcessKind.Executable;
        }

        /// <summary>
        /// Initializes a new instance of the ExecutableObserver class.
        /// </summary>
        /// <param name="id">Thread identificator.</param>
        /// <param name="fileName">Observed file name.</param>
        /// <param name="scanFrequency">Scan frequency [seconds].</param>
        public ExecutableObserver(string id, string fileName, int scanFrequency)
            : base(id, fileName, scanFrequency)
        {
        }
        #endregion

        #region overriden methods
        /// <summary>
        /// Tests service status.
        /// </summary>
        /// <returns>Current executable file status.</returns>
        protected sealed override ProcessStatus TestStatus()
        {
            ProcessStatus currentStatus = ProcessStatus.Stopped; // current process status

            try {
                foreach ( System.Diagnostics.Process process in System.Diagnostics.Process.GetProcesses() ) {
                    if ( this.Name.Equals(process.MainModule.FileName) ) {
                        currentStatus = ProcessStatus.Started; // marks status as 'running'
                    }
                }
            }
            catch ( System.PlatformNotSupportedException ) { // (Process.MainModule)
                currentStatus = ProcessStatus.Unknown;
            }
            catch ( System.NotSupportedException ) { // (Process.MainModule)
                currentStatus = ProcessStatus.Unknown;
            }
            catch ( System.InvalidOperationException ) { // (Process.MainModule)
                currentStatus = ProcessStatus.Unknown;
            }
            catch ( System.ComponentModel.Win32Exception ) { } // (Process.MainModule)

            return currentStatus;
        }
        #endregion
    }
    #endregion
}
